View source: R/reactCheckbox.R
| checkbox | R Documentation |
Define a checkbox by its label, its value, and optionally a CSS class.
checkbox(label, value, class = "")
label |
the label of the checkbox, can be an ordinary character string,
a |
value |
the initial value of the checkbox, |
class |
the name of a CSS class to attach to the checkbox, that should
be defined with |
A named list, to be used in reactCheckboxesInput.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.